==> react-ui-5.0.0.tgz: package/SplitButton.js <==
/******/ (() => {
    // webpackBootstrap
    /******/ "use strict";
    /******/ // The require scope
    /******/    var e = {};
    /******/
    /************************************************************************/
    /******/ /* webpack/runtime/compat get default export */
    /******/    (() => {
        /******/ // getDefaultExport function for compatibility with non-harmony modules
        /******/ e.n = n => {
            /******/ var r = n && n.__esModule ? 
            /******/ () => n["default"]
            /******/ : () => n
            /******/;
            e.d(r, {
                a: r
            });
            /******/            return r;
            /******/        };
        /******/    })();
    /******/
    /******/ /* webpack/runtime/define property getters */
    /******/    (() => {
        /******/ // define getter functions for harmony exports
        /******/ e.d = (n, r) => {
            /******/ for (var t in r) {
                /******/ if (e.o(r, t) && !e.o(n, t)) {
                    /******/ Object.defineProperty(n, t, {
                        enumerable: true,
                        get: r[t]
                    });
                    /******/                }
                /******/            }
            /******/        };
        /******/    })();
    /******/
    /******/ /* webpack/runtime/hasOwnProperty shorthand */
    /******/    (() => {
        /******/ e.o = (e, n) => Object.prototype.hasOwnProperty.call(e, n)
        /******/;
    })();
    /******/
    /******/ /* webpack/runtime/make namespace object */
    /******/    (() => {
        /******/ // define __esModule on exports
        /******/ e.r = e => {
            /******/ if (typeof Symbol !== "undefined" && Symbol.toStringTag) {
                /******/ Object.defineProperty(e, Symbol.toStringTag, {
                    value: "Module"
                });
                /******/            }
            /******/            Object.defineProperty(e, "__esModule", {
                value: true
            });
            /******/        };
        /******/    })();
    /******/
    /************************************************************************/    var n = {};
    // ESM COMPAT FLAG
        e.r(n);
    // EXPORTS
        e.d(n, {
        Item: () => /* reexport */ P,
        default: () => /* reexport */ T
    });
    // CONCATENATED MODULE: external "react"
    const r = require("react");
    var t =  e.n(r);
    // CONCATENATED MODULE: external "prop-types"
    const a = require("prop-types");
    var i =  e.n(a);
    // CONCATENATED MODULE: external "@splunk/react-icons/CaretSmallDown"
    const l = require("@splunk/react-icons/CaretSmallDown");
    var o =  e.n(l);
    // CONCATENATED MODULE: external "@splunk/react-ui/Dropdown"
    const c = require("@splunk/react-ui/Dropdown");
    var u =  e.n(c);
    // CONCATENATED MODULE: external "@splunk/react-ui/Menu"
    const s = require("@splunk/react-ui/Menu");
    var d =  e.n(s);
    // CONCATENATED MODULE: external "@splunk/ui-utils/i18n"
    const p = require("@splunk/ui-utils/i18n");
    // CONCATENATED MODULE: external "styled-components"
    const f = require("styled-components");
    var v =  e.n(f);
    // CONCATENATED MODULE: external "@splunk/react-ui/Button"
    const b = require("@splunk/react-ui/Button");
    var y =  e.n(b);
    // CONCATENATED MODULE: external "@splunk/themes"
    const m = require("@splunk/themes");
    // CONCATENATED MODULE: ./src/SplitButton/SplitButtonStyles.ts
    var g = v()(y()).withConfig({
        displayName: "SplitButtonStyles__StyledToggle",
        componentId: "sc-9igsyh-0"
    })([ "min-width:0;width:24px;" ]);
    var h = v().div.withConfig({
        displayName: "SplitButtonStyles__StyledDiv",
        componentId: "sc-9igsyh-1"
    })([ "", " ", " ", "" ], m.mixins.reset("inline-flex"), (function(e) {
        var n = e.$appearance;
        return (n === "primary" || n === "destructive") && (0, f.css)([ "gap:1px;" ]);
    }), (function(e) {
        var n = e.$inline;
        return !n && (0, f.css)([ "width:100%;" ]);
    }));
    // CONCATENATED MODULE: external "lodash/omit"
    const O = require("lodash/omit");
    var S =  e.n(O);
    // CONCATENATED MODULE: ./src/SplitButton/Item.tsx
    function k() {
        return k = Object.assign ? Object.assign.bind() : function(e) {
            for (var n = 1; n < arguments.length; n++) {
                var r = arguments[n];
                for (var t in r) {
                    ({}).hasOwnProperty.call(r, t) && (e[t] = r[t]);
                }
            }
            return e;
        }, k.apply(null, arguments);
    }
    function w(e, n) {
        if (null == e) return {};
        var r, t, a = C(e, n);
        if (Object.getOwnPropertySymbols) {
            var i = Object.getOwnPropertySymbols(e);
            for (t = 0; t < i.length; t++) {
                r = i[t], n.includes(r) || {}.propertyIsEnumerable.call(e, r) && (a[r] = e[r]);
            }
        }
        return a;
    }
    function C(e, n) {
        if (null == e) return {};
        var r = {};
        for (var t in e) {
            if ({}.hasOwnProperty.call(e, t)) {
                if (n.includes(t)) continue;
                r[t] = e[t];
            }
        }
        return r;
    }
    /** @public */    var j = {
        appearance: i().oneOf([ "default", "secondary", "primary", "destructive", "destructiveSecondary" ]),
        children: i().node,
        disabled: i().bool,
        elementRef: i().oneOfType([ i().func, i().object ]),
        icon: i().node,
        isMain: i().bool,
        onClick: i().func
    };
    /**
 * An item within a `SplitButton`.
 */    function E(e) {
        var n = e.appearance, a = n === void 0 ? "secondary" : n, i = e.disabled, l = e.elementRef, o = e.icon, c = e.isMain, u = e.children, s = e.onClick, p = w(e, [ "appearance", "disabled", "elementRef", "icon", "isMain", "children", "onClick" ]);
        // @docs-props-type ItemPropsBase
                var f = (0, r.useCallback)((function(e) {
            if (!i) {
                s === null || s === void 0 ? void 0 : s(e, {});
            }
        }), [ i, s ]);
        var v = (0, r.useCallback)((function(e, n) {
            var r = n.action, t = n.icon, a = n.label, l = n.value;
            if (!i) {
                s === null || s === void 0 ? void 0 : s(e, {
                    action: r,
                    icon: t,
                    label: a,
                    value: l
                });
            }
        }), [ i, s ]);
        if (c) {
            
            return t().createElement(y(), k({
                appearance: a,
                append: true,
                disabled: i,
                elementRef: l,
                icon: o,
                onClick: v
            }, p), u);
        }
        
        return t().createElement(d().Item, k({
            disabled: i,
            elementRef: l,
            onClick: f,
            startAdornment: o
        }, S()(p, [ "role" ])), u);
    }
    E.propTypes = j;
    /* harmony default export */    const P = E;
    // CONCATENATED MODULE: ./src/SplitButton/SplitButton.tsx
    function q() {
        return q = Object.assign ? Object.assign.bind() : function(e) {
            for (var n = 1; n < arguments.length; n++) {
                var r = arguments[n];
                for (var t in r) {
                    ({}).hasOwnProperty.call(r, t) && (e[t] = r[t]);
                }
            }
            return e;
        }, q.apply(null, arguments);
    }
    function _(e, n) {
        if (null == e) return {};
        var r, t, a = M(e, n);
        if (Object.getOwnPropertySymbols) {
            var i = Object.getOwnPropertySymbols(e);
            for (t = 0; t < i.length; t++) {
                r = i[t], n.includes(r) || {}.propertyIsEnumerable.call(e, r) && (a[r] = e[r]);
            }
        }
        return a;
    }
    function M(e, n) {
        if (null == e) return {};
        var r = {};
        for (var t in e) {
            if ({}.hasOwnProperty.call(e, t)) {
                if (n.includes(t)) continue;
                r[t] = e[t];
            }
        }
        return r;
    }
    var R = {
        appearance: i().oneOf([ "default", "secondary", "primary", "destructive", "destructiveSecondary" ]),
        children: i().node,
        disabled: i().bool,
        elementRef: i().oneOfType([ i().func, i().object ]),
        onClick: i().func,
        inline: i().bool
    };
    function I(e) {
        var n = e.appearance, a = n === void 0 ? "secondary" : n, i = e.children, l = e.disabled, c = e.elementRef, s = e.inline, f = s === void 0 ? true : s, v = e.onClick, b = _(e, [ "appearance", "children", "disabled", "elementRef", "inline", "onClick" ]);
 // @docs-props-type SplitButtonPropsBase
                var y = r.Children.toArray(i).filter(r.isValidElement);
        var m = 0;
        var O = 0;
        y.forEach((function(e, n) {
            var r = e.props, t = r.disabled, a = r.isMain;
            if (a) {
                m = n;
            }
            if (t) {
                O += 1;
            }
        }));
        var S =  (0, r.cloneElement)(y[m], {
            isMain: true,
            appearance: a,
            disabled: l || y[m].props.disabled
        });
        // Remove mainButton from array of dropdown items
                y.splice(m, 1);
        var k = y;
        var w =  t().createElement(g, {
            prepend: true,
            disabled: l || O === k.length,
            appearance: a,
            "data-test": "split-button-toggle",
            "aria-label": (0, p._)("Open more options"),
            icon:  t().createElement(o(), null)
        });
        
        return t().createElement(h, q({
            "aria-label": (0, p._)("Split button"),
            "data-inline": f || null,
            "data-test": "split-button-container",
            $inline: f,
            ref: c,
            role: "group",
            onClick: l ? undefined : v,
            $appearance: a
        }, b), S,  t().createElement("div", null,  t().createElement(u(), {
            toggle: w
        },  t().createElement(d(), null, k))));
    }
    I.propTypes = R;
    I.Item = P;
    /* harmony default export */    const T = I;
    // CONCATENATED MODULE: ./src/SplitButton/index.ts
    module.exports = n;
    /******/})();

==> react-ui-5.1.0.tgz: package/SplitButton.js <==
/******/ (() => {
    // webpackBootstrap
    /******/ "use strict";
    /******/ // The require scope
    /******/    var e = {};
    /******/
    /************************************************************************/
    /******/ /* webpack/runtime/compat get default export */
    /******/    (() => {
        /******/ // getDefaultExport function for compatibility with non-harmony modules
        /******/ e.n = n => {
            /******/ var r = n && n.__esModule ? 
            /******/ () => n["default"]
            /******/ : () => n
            /******/;
            e.d(r, {
                a: r
            });
            /******/            return r;
            /******/        };
        /******/    })();
    /******/
    /******/ /* webpack/runtime/define property getters */
    /******/    (() => {
        /******/ // define getter functions for harmony exports
        /******/ e.d = (n, r) => {
            /******/ for (var t in r) {
                /******/ if (e.o(r, t) && !e.o(n, t)) {
                    /******/ Object.defineProperty(n, t, {
                        enumerable: true,
                        get: r[t]
                    });
                    /******/                }
                /******/            }
            /******/        };
        /******/    })();
    /******/
    /******/ /* webpack/runtime/hasOwnProperty shorthand */
    /******/    (() => {
        /******/ e.o = (e, n) => Object.prototype.hasOwnProperty.call(e, n)
        /******/;
    })();
    /******/
    /******/ /* webpack/runtime/make namespace object */
    /******/    (() => {
        /******/ // define __esModule on exports
        /******/ e.r = e => {
            /******/ if (typeof Symbol !== "undefined" && Symbol.toStringTag) {
                /******/ Object.defineProperty(e, Symbol.toStringTag, {
                    value: "Module"
                });
                /******/            }
            /******/            Object.defineProperty(e, "__esModule", {
                value: true
            });
            /******/        };
        /******/    })();
    /******/
    /************************************************************************/    var n = {};
    // ESM COMPAT FLAG
        e.r(n);
    // EXPORTS
        e.d(n, {
        Item: () => /* reexport */ k,
        default: () => /* reexport */ T
    });
    // CONCATENATED MODULE: external "react"
    const r = require("react");
    var t =  e.n(r);
    // CONCATENATED MODULE: external "prop-types"
    const a = require("prop-types");
    var i =  e.n(a);
    // CONCATENATED MODULE: external "@splunk/react-icons/CaretSmallDown"
    const l = require("@splunk/react-icons/CaretSmallDown");
    var o =  e.n(l);
    // CONCATENATED MODULE: external "@splunk/react-ui/Dropdown"
    const c = require("@splunk/react-ui/Dropdown");
    var u =  e.n(c);
    // CONCATENATED MODULE: external "@splunk/react-ui/Menu"
    const s = require("@splunk/react-ui/Menu");
    var d =  e.n(s);
    // CONCATENATED MODULE: external "@splunk/ui-utils/i18n"
    const p = require("@splunk/ui-utils/i18n");
    // CONCATENATED MODULE: external "lodash/omit"
    const f = require("lodash/omit");
    var v =  e.n(f);
    // CONCATENATED MODULE: external "@splunk/react-ui/Button"
    const b = require("@splunk/react-ui/Button");
    var y =  e.n(b);
    // CONCATENATED MODULE: ./src/SplitButton/Item.tsx
    function m() {
        return m = Object.assign ? Object.assign.bind() : function(e) {
            for (var n = 1; n < arguments.length; n++) {
                var r = arguments[n];
                for (var t in r) {
                    ({}).hasOwnProperty.call(r, t) && (e[t] = r[t]);
                }
            }
            return e;
        }, m.apply(null, arguments);
    }
    function g(e, n) {
        if (null == e) return {};
        var r, t, a = h(e, n);
        if (Object.getOwnPropertySymbols) {
            var i = Object.getOwnPropertySymbols(e);
            for (t = 0; t < i.length; t++) {
                r = i[t], n.includes(r) || {}.propertyIsEnumerable.call(e, r) && (a[r] = e[r]);
            }
        }
        return a;
    }
    function h(e, n) {
        if (null == e) return {};
        var r = {};
        for (var t in e) {
            if ({}.hasOwnProperty.call(e, t)) {
                if (n.includes(t)) continue;
                r[t] = e[t];
            }
        }
        return r;
    }
    /** @public */    var O = {
        appearance: i().oneOf([ "default", "secondary", "primary", "destructive", "destructiveSecondary" ]),
        children: i().node,
        disabled: i().bool,
        elementRef: i().oneOfType([ i().func, i().object ]),
        icon: i().node,
        isMain: i().bool,
        onClick: i().func
    };
    /**
 * An item within a `SplitButton`.
 */    function S(e) {
        var n = e.appearance, a = n === void 0 ? "secondary" : n, i = e.disabled, l = e.elementRef, o = e.icon, c = e.isMain, u = e.children, s = e.onClick, p = g(e, [ "appearance", "disabled", "elementRef", "icon", "isMain", "children", "onClick" ]);
        // @docs-props-type ItemPropsBase
                var f = (0, r.useCallback)((function(e) {
            if (!i) {
                s === null || s === void 0 ? void 0 : s(e, {});
            }
        }), [ i, s ]);
        var b = (0, r.useCallback)((function(e, n) {
            var r = n.action, t = n.icon, a = n.label, l = n.value;
            if (!i) {
                s === null || s === void 0 ? void 0 : s(e, {
                    action: r,
                    icon: t,
                    label: a,
                    value: l
                });
            }
        }), [ i, s ]);
        if (c) {
            
            return t().createElement(y(), m({
                appearance: a,
                append: true,
                disabled: i,
                elementRef: l,
                icon: o,
                onClick: b
            }, p), u);
        }
        
        return t().createElement(d().Item, m({
            disabled: i,
            elementRef: l,
            onClick: f,
            startAdornment: o
        }, v()(p, [ "role" ])), u);
    }
    S.propTypes = O;
    /* harmony default export */    const k = S;
    // CONCATENATED MODULE: external "styled-components"
    const w = require("styled-components");
    var C =  e.n(w);
    // CONCATENATED MODULE: external "@splunk/themes"
    const j = require("@splunk/themes");
    // CONCATENATED MODULE: ./src/SplitButton/SplitButtonStyles.ts
    var E = C()(y()).withConfig({
        displayName: "SplitButtonStyles__StyledToggle",
        componentId: "sc-9igsyh-0"
    })([ "min-width:0;width:24px;" ]);
    var P = C().div.withConfig({
        displayName: "SplitButtonStyles__StyledDiv",
        componentId: "sc-9igsyh-1"
    })([ "", " ", " ", "" ], j.mixins.reset("inline-flex"), (function(e) {
        var n = e.$appearance;
        return (n === "primary" || n === "destructive") && (0, w.css)([ "gap:1px;" ]);
    }), (function(e) {
        var n = e.$inline;
        return !n && (0, w.css)([ "width:100%;" ]);
    }));
    // CONCATENATED MODULE: ./src/SplitButton/SplitButton.tsx
    function q() {
        return q = Object.assign ? Object.assign.bind() : function(e) {
            for (var n = 1; n < arguments.length; n++) {
                var r = arguments[n];
                for (var t in r) {
                    ({}).hasOwnProperty.call(r, t) && (e[t] = r[t]);
                }
            }
            return e;
        }, q.apply(null, arguments);
    }
    function _(e, n) {
        if (null == e) return {};
        var r, t, a = M(e, n);
        if (Object.getOwnPropertySymbols) {
            var i = Object.getOwnPropertySymbols(e);
            for (t = 0; t < i.length; t++) {
                r = i[t], n.includes(r) || {}.propertyIsEnumerable.call(e, r) && (a[r] = e[r]);
            }
        }
        return a;
    }
    function M(e, n) {
        if (null == e) return {};
        var r = {};
        for (var t in e) {
            if ({}.hasOwnProperty.call(e, t)) {
                if (n.includes(t)) continue;
                r[t] = e[t];
            }
        }
        return r;
    }
    var R = {
        appearance: i().oneOf([ "default", "secondary", "primary", "destructive", "destructiveSecondary" ]),
        children: i().node,
        disabled: i().bool,
        elementRef: i().oneOfType([ i().func, i().object ]),
        onClick: i().func,
        inline: i().bool
    };
    function I(e) {
        var n = e.appearance, a = n === void 0 ? "secondary" : n, i = e.children, l = e.disabled, c = e.elementRef, s = e.inline, f = s === void 0 ? true : s, v = e.onClick, b = _(e, [ "appearance", "children", "disabled", "elementRef", "inline", "onClick" ]);
 // @docs-props-type SplitButtonPropsBase
                var y = r.Children.toArray(i).filter(r.isValidElement);
        var m = 0;
        var g = 0;
        y.forEach((function(e, n) {
            var r = e.props, t = r.disabled, a = r.isMain;
            if (a) {
                m = n;
            }
            if (t) {
                g += 1;
            }
        }));
        var h =  (0, r.cloneElement)(y[m], {
            isMain: true,
            appearance: a,
            disabled: l || y[m].props.disabled
        });
        // Remove mainButton from array of dropdown items
                y.splice(m, 1);
        var O = y;
        var S =  t().createElement(E, {
            prepend: true,
            disabled: l || g === O.length,
            appearance: a,
            "data-test": "split-button-toggle",
            "aria-label": (0, p._)("Open more options"),
            icon:  t().createElement(o(), null)
        });
        
        return t().createElement(P, q({
            "aria-label": (0, p._)("Split button"),
            "data-inline": f || null,
            "data-test": "split-button-container",
            $inline: f,
            ref: c,
            role: "group",
            onClick: l ? undefined : v,
            $appearance: a
        }, b), h,  t().createElement("div", null,  t().createElement(u(), {
            toggle: S
        },  t().createElement(d(), null, O))));
    }
    I.propTypes = R;
    I.Item = k;
    /* harmony default export */    const T = I;
    // CONCATENATED MODULE: ./src/SplitButton/index.ts
    module.exports = n;
    /******/})();
